@@ -1,11 +1,11 @@
 # coding: utf-8
 
 __name__        = "kvaser"
-__version__     = "0.0.10"
+__version__     = "0.0.12"
 __license__     = "Apache Software License"
 __description__ = "Various utility functions."
 __author__      = u"Klaus Kähler Holst"
-__email__       = "klaus.holst@maersk.com"
+__email__       = "klaus@holst.it"
 __url__         = "https://github.com/kkholst/kvaser"
 __copyright__   = u"Copyright 2019-2022, Klaus Kähler Holst"
 __summary__     = "Utility functions"
